@@ -28,7 +28,7 @@ extern "C" {
  * has been modified, and reset anytime the major API version has
  * been changed. Used to keep track if a field has been added or not.
  */
-#define SVT_AV1_ENC_ABI_VERSION 4
+#define SVT_AV1_ENC_ABI_VERSION 6
 
 //***HME***
 
@@ -177,6 +177,27 @@ typedef enum EbSFrameMode {
         2, /**< If the considered frame is not an altref frame, the next base layer inter frame will be made into an S-Frame */
 } EbSFrameMode;
 
+/* Indicates what prediction structure to use
+ * was PredStructure in EbDefinitions.h
+ * Only SVT_AV1_PRED_LOW_DELAY_B and SVT_AV1_PRED_RANDOM_ACCESS are valid
+ */
+typedef enum SvtAv1PredStructure {
+    SVT_AV1_PRED_LOW_DELAY_P   = 0, // No longer active
+    SVT_AV1_PRED_LOW_DELAY_B   = 1,
+    SVT_AV1_PRED_RANDOM_ACCESS = 2,
+    SVT_AV1_PRED_TOTAL_COUNT   = 3,
+    SVT_AV1_PRED_INVALID       = 0xFF,
+} SvtAv1PredStructure;
+
+/* Indicates what rate control mode is used.
+ * Currently, cqp is distinguised by setting enable_adaptive_quantization to 0
+ */
+typedef enum SvtAv1RcMode {
+    SVT_AV1_RC_MODE_CQP_OR_CRF = 0, // constant quantization parameter/constant rate factor
+    SVT_AV1_RC_MODE_VBR        = 1, // variable bit rate
+    SVT_AV1_RC_MODE_CBR        = 2, // constant bit rate
+} SvtAv1RcMode;
+
 // Will contain the EbEncApi which will live in the EncHandle class
 // Only modifiable during config-time.
 typedef struct EbSvtAv1EncConfiguration {
@@ -214,10 +235,11 @@ typedef struct EbSvtAv1EncConfiguration {
      *
      * Default is 1. */
     SvtAv1IntraRefreshType intra_refresh_type;
+
     /* Number of hierarchical layers used to construct GOP.
      * Minigop size = 2^HierarchicalLevels.
      *
-     * Default is 3. */
+     * Default is 5 upt to M12 4, for M13. */
     uint32_t hierarchical_levels;
 
     /* Prediction structure used to construct GOP. There are two main structures
@@ -235,7 +257,9 @@ typedef struct EbSvtAv1EncConfiguration {
      * In Random Access structure, the B/b pictures can refer to reference pictures
      * from both directions (past and future).
      *
-     * Default is 2. */
+     * Refer to SvtAv1PredStructure enum for valid values.
+     *
+     * Default is SVT_AV1_PRED_RANDOM_ACCESS. */
     uint8_t pred_structure;
 
     // Input Info
@@ -292,10 +316,11 @@ typedef struct EbSvtAv1EncConfiguration {
      * Default is YUV420.
      */
     EbColorFormat encoder_color_format;
-    /* Offline packing of the 2bits: requires two bits packed input.
-     *
-     * Default is 0. */
+
+#if !SVT_AV1_CHECK_VERSION(1, 5, 0)
+    /* DEPRECATED: to be removed in 1.5.0. */
     uint32_t compressed_ten_bit_format;
+#endif
 
     /**
      * @brief Enable writing of HDR metadata in the bitstream
@@ -380,9 +405,7 @@ typedef struct EbSvtAv1EncConfiguration {
 
     /* Rate control mode.
      *
-     * 0 = Constant QP.
-     * 1 = Variable Bit Rate, achieve the target bitrate at entire stream.
-     * 2 = Constant Bit Rate, achieve the target bitrate
+     * Refer to the SvtAv1RcMode enum for valid values
      * Default is 0. */
     uint32_t rate_control_mode;
 
@@ -411,8 +434,8 @@ typedef struct EbSvtAv1EncConfiguration {
      * Default is 0. */
     uint32_t max_bit_rate;
 
-#if !SVT_AV1_CHECK_VERSION(1, 3, 0)
-    /* DEPRECATED: to be removed in 1.3.0. */
+#if !SVT_AV1_CHECK_VERSION(1, 5, 0)
+    /* DEPRECATED: to be removed in 1.5.0. */
     uint32_t vbv_bufsize;
 #endif
 
@@ -427,39 +450,130 @@ typedef struct EbSvtAv1EncConfiguration {
      * Default is 0. */
     uint32_t min_qp_allowed;
 
-    /* DATARATE CONTROL OPTIONS.
-     * Indicates the bias (expressed on a scale of 0 to 100) for determining
-     * target size for the current frame. The value 0 indicates the optimal CBR
-     * mode value should be used, and 100 indicates the optimal VBR mode value
-     * should be used. */
+    // DATARATE CONTROL OPTIONS
+
+    /**
+     * @brief Variable Bit Rate Bias Percentage
+     *
+     * Indicates the bias for determining target size for the current frame.
+     * A value 0 indicates the optimal CBR mode value should be used, and 100
+     * indicates the optimal VBR mode value should be used.
+     *
+     * Min is 0.
+     * Max is 100.
+     * Default is 100
+     */
     uint32_t vbr_bias_pct;
-    /* Indicates the minimum bitrate to be used for a single GOP as a percentage
-     * of the target bitrate. */
+
+    /**
+     * @brief Variable Bit Rate Minimum Section Percentage
+     *
+     * Indicates the minimum bitrate to be used for a single GOP as a percentage
+     * of the target bitrate.
+     *
+     * Min is 0.
+     * Max is 100.
+     * Default is 0.
+     */
     uint32_t vbr_min_section_pct;
-    /* Indicates the maximum bitrate to be used for a single GOP as a percentage
-     * of the target bitrate. */
+
+    /**
+     * @brief Variable Bit Rate Maximum Section Percentage
+     *
+     * Indicates the maximum bitrate to be used for a single GOP as a percentage
+     * of the target bitrate.
+     *
+     * Min is 0.
+     * Max is 10000.
+     * Default is 2000.
+     */
     uint32_t vbr_max_section_pct;
-    /* under_shoot_pct indicates the tolerance of the VBR algorithm to undershoot
-     * and is used as a trigger threshold for more agressive adaptation of Q. Its
-     * value can range from 0-100. */
+
+    /**
+     * @brief UnderShoot Percentage
+     *
+     * Only applicable for VBR and CBR.
+     *
+     * Indicates the tolerance of the VBR algorithm to undershoot and is used
+     * as a trigger threshold for more agressive adaptation of Quantization.
+     *
+     * Min is 0.
+     * Max is 100.
+     * Default is 25.
+     */
     uint32_t under_shoot_pct;
-    /* over_shoot_pct indicates the tolerance of the VBR algorithm to overshoot
-     * and is used as a trigger threshold for more agressive adaptation of Q. Its
-     * value can range from 0-1000. */
+
+    /**
+     * @brief OverShoot Percentage
+     *
+     * Only applicable for VBR and CBR
+     *
+     * Indicates the tolerance of the VBR algorithm to overshoot and is used as
+     * a trigger threshold for more agressive adaptation of Quantization.
+     *
+     * Min is 0.
+     * Max is 100.
+     * Default is 25.
+     */
     uint32_t over_shoot_pct;
-    /* over_shoot_pct indicates the tolerance of the Capped CRF algorithm to overshoot
-     * and is used as a trigger threshold for more agressive adaptation of Q. Its
-     * value can range from 0-1000. */
+
+    /**
+     * @brief MaxBitRate OverShoot Percentage
+     *
+     * Only applicable for Capped CRF.
+     *
+     * Indicates the tolerance of the Capped CRF algorithm to overshoot
+     * and is used as a trigger threshold for more agressive adaptation of
+     * Quantization.
+     *
+     * Min is 0.
+     * Max is 100.
+     * Default is 50.
+     */
     uint32_t mbr_over_shoot_pct;
-    /* Indicates the amount of data that will be buffered by the decoding
+
+    /**
+     * @brief Starting Buffer Level in MilliSeconds
+     *
+     * Only applicable for CBR.
+     *
+     * Indicates the amount of data that will be buffered by the decoding
      * application prior to beginning playback, and is expressed in units of
-     * time(milliseconds). */
+     * time. Must be less than maximum_buffer_size_ms.
+     *
+     * Min is 20.
+     * Max is 10000.
+     * Default is 600.
+     */
     int64_t starting_buffer_level_ms;
-    /* Indicates the amount of data that the encoder should try to maintain in the
-     * decoder's buffer, and is expressed in units of time(milliseconds). */
+
+    /**
+     * @brief Optimal Buffer Level in MilliSeconds
+     *
+     * Only applicable for CBR.
+     *
+     * indicates the amount of data that the encoder should try to maintain in the
+     * decoder's buffer, and is expressed in units of time. Must be less than
+     * maximum_buffer_size_ms.
+     *
+     * Min is 20.
+     * Max is 10000.
+     * Default is 600.
+     */
     int64_t optimal_buffer_level_ms;
-    /* Indicates the maximum amount of data that may be buffered by the decoding
-     * application, and is expressed in units of time(milliseconds).*/
+
+    /**
+     * @brief Maximum Buffer Size in MilliSeconds
+     *
+     * Only applicable for CBR.
+     *
+     * indicates the maximum amount of data that may be buffered by the
+     * decoding application, and is expressed in units of time.
+     *
+     * Min is 20.
+     * Max is 10000.
+     * Default is 1000.
+     */
     int64_t maximum_buffer_size_ms;
 
     // input / output buffer to be used for multi-pass encoding
@@ -602,30 +716,16 @@ typedef struct EbSvtAv1EncConfiguration {
     uint8_t superres_kf_qthres;
     uint8_t superres_auto_search_type;
 
-    /**
-     * @brief API signal containing the manual prediction structure parameters.
-     * Only used when enable_manual_pred_struct is enabled. This list is copied
-     * into internal buffers after svt_av1_enc_set_parameter().
-     */
+#if !SVT_AV1_CHECK_VERSION(1, 5, 0)
+    /* DEPRECATED: to be removed in 1.5.0. */
     PredictionStructureConfigEntry pred_struct[1 << (MAX_HIERARCHICAL_LEVEL - 1)];
 
-    /**
-     * @brief API signal to overwrite the encoder's default prediction structure.
-     *
-     * Default is false.
-     */
+    /* DEPRECATED: to be removed in 1.5.0. */
     Bool enable_manual_pred_struct;
 
-    /**
-     * @brief API signal specifying the size (number of entries) of the manual prediction structure buffer.
-     * Only checked and used when enable_manual_pred_struct is enabled.
-     *
-     * Min is 1.
-     * Max is 32.
-     * Default is 0.
-     */
+    /* DEPRECATED: to be removed in 1.5.0. */
     int32_t manual_pred_struct_entry_num;
-
+#endif
     /* Decoder-speed-targeted encoder optimization level (produce bitstreams that can be decoded faster).
     * 0: No decoder speed optimization
     * 1: Decoder speed optimization enabled (fast decode)
@@ -760,6 +860,19 @@ typedef struct EbSvtAv1EncConfiguration {
      * Default is 15.
      */
     uint8_t max_qm_level;
+
+    /**
+     * @brief gop_constraint_rc
+     *
+     * Currently, only applicable for VBR and  when GoP size is greater than 119 frames.
+     *
+     * When enabled, the rate control matches the target rate for each GoP.
+     *
+     * 0: off
+     * 1: on
+     * Default is 0.
+     */
+    Bool gop_constraint_rc;
 } EbSvtAv1EncConfiguration;
 
 /**
